# coding: utf-8
require "thor"
require "net/ping"
require "yaml"
require "logger"

module Fritz
  class Ping < Thor
    @@logger = Logger.new($stdout, shift_age = 'weekly')

    desc "host ADDRESS","Uses external ping command to ping one single host."
    method_option :out, aliases: "-o", default: false, desc: "Whether the hosts status should be printed to STDOUT."
    def host(address)
      p = Net::Ping::External.new(address)
      puts "#{address} #{p.ping?}" if options.out?
      p.ping?
    end

    desc "hosts FILE", "Pings all addresses in a yaml file."
    method_option :logfile, aliases: "-l", desc: "Location of the writable logfile."
    def hosts(file)
      @@logger = Logger.new(options[:logfile], shift_age = 'weekly') unless options[:logfile].nil?
      hosts = YAML.load(File.open(file))
      hosts.each do |label, addresses|
        addresses.each do |address|
          @@logger.add Logger::Severity::INFO, "#{label}\t#{address}\t#{self.host(address)}"
        end
      end
    end
  end
end
